FakePubspecVersion class

A fake PubspecVersion working on e pubspec.yaml file.

Inheritance

Constructors

FakePubspecVersion()
Creates a FakePubspecVersion.

Properties

hashCode int
The hash code for this object.
no setterinherited
pubspecFile File
Returns the pubspec.yaml File.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
version({required PubspecVersionCommand versionCommand, bool dryRun = false}) Future<String?>
Execute versionCommand.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited