PubspecVersion class

A utility class for managing the version string in pubspec.yaml.

Implementers

Constructors

PubspecVersion()
constructor for the singleton pattern, only visible for testing

Properties

hashCode int
The hash code for this object.
no setterinherited
pubspecFile File
Returns the pubspec.yaml File.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
version({required PubspecVersionCommand versionCommand, bool dryRun = false}) Future<String?>
Execute versionCommand.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PubspecVersion
The singleton instance of PubspecVersion.
getter/setter pair