PubspecVersion constructor
PubspecVersion()
constructor for the singleton pattern, only visible for testing
Implementation
PubspecVersion();
constructor for the singleton pattern, only visible for testing
PubspecVersion();