PubspecVersionCommand enum
The version commands
Values
- major → const PubspecVersionCommand
-
Increment the major version.
- minor → const PubspecVersionCommand
-
Increment the minor version.
- patch → const PubspecVersionCommand
-
Increment the patch version.
- build → const PubspecVersionCommand
-
Increment the build number.
- show → const PubspecVersionCommand
-
Show the current version.
- showBuild → const PubspecVersionCommand
-
Show the current build number.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String command) → PubspecVersionCommand -
Returns the PubspecVersionCommand from the given
command.
Constants
-
values
→ const List<
PubspecVersionCommand> - A constant List of the values in this enum, in order of their declaration.